// ===========================================================================
// CONTENT  : TEST CLASS NLSIniFileLoaderTest
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 24/03/2006
// HISTORY  :
//  24/03/2006  duma  CREATED
//
// Copyright (c) 2006, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pf.nls;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.io.File;
import java.util.Locale;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Test class for corresponding business class.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class NLSIniFileLoaderTest extends TestCase
{
	// =========================================================================
	// CONSTANTS
	// =========================================================================
	protected static final String TESTDATA = UnitTestHelper.TESTDATA;
	protected static final File FILE_1 = new File(TESTDATA + "nls-sample1.ini");

	// =========================================================================
	// INSTANCE VARIABLES
	// =========================================================================

	// =========================================================================
	// CONSTRUCTORS
	// =========================================================================
	/**
	 * Initialize the new instance with default values.
	 */
	public NLSIniFileLoaderTest(String name)
	{
		super(name);
	} // NLSIniFileLoaderTest() 

	// =========================================================================
	// PUBLIC CLASS METHODS
	// =========================================================================
	public static Test suite()
	{
		return new TestSuite(NLSIniFileLoaderTest.class);
	} // suite() 

	// =========================================================================
	// TEST METHODS
	// =========================================================================

	public void test_loadText_1() throws Exception
	{
		NLSIniFileLoader loader = new NLSIniFileLoader();
		TextContainer container;

		container = loader.loadText(FILE_1, Locale.GERMAN);
		assertEquals("de", container.getLocale().toString());
		assertEquals("Datei schließen", container.getText("label.close.file"));
		assertEquals("Datei nicht gefunden!", container.getText("msg.file.not.found"));
		assertEquals("Angaben für Rückmeldung", container.getText("msg.feedback"));
		assertNull(container.getText("help.export.csv"));
	} // test_loadText_1() 

	// -------------------------------------------------------------------------

	public void test_loadText_2() throws Exception
	{
		NLSIniFileLoader loader = new NLSIniFileLoader();
		TextContainer container;

		container = loader.loadText(FILE_1, "en");
		assertEquals("en", container.getLocale().toString());
		assertEquals("Close File", container.getText("label.close.file"));
		assertEquals("File not found!", container.getText("msg.file.not.found"));
		assertEquals("Provide feedback", container.getText("msg.feedback"));
		assertEquals("Export all data to a CSV file", container.getText("help.export.csv"));
	} // test_loadText_2() 

	// -------------------------------------------------------------------------

	// =========================================================================
	// PROTECTED INSTANCE METHODS
	// =========================================================================
	@Override
  protected void setUp() throws Exception
	{
		super.setUp();
	} // setUp() 

	// -------------------------------------------------------------------------

} // class NLSIniFileLoaderTest 
