// ===========================================================================
// CONTENT  : TEST CLASS TextContainerListTest
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 25/03/2006
// HISTORY  :
//  25/03/2006  duma  CREATED
//
// Copyright (c) 2006, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pf.nls;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.io.File;
import java.util.Locale;

import junit.framework.*;

/**
 * Test class for corresponding business class.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class TextContainerListTest extends TestCase
{
	// =========================================================================
	// CONSTANTS
	// =========================================================================
	protected static final String TESTDATA = UnitTestHelper.TESTDATA;
	protected static final File FILE_1 = new File(TESTDATA + "nls-sample1.ini");

	// =========================================================================
	// INSTANCE VARIABLES
	// =========================================================================

	// =========================================================================
	// CONSTRUCTORS
	// =========================================================================
	/**
	 * Initialize the new instance with default values.
	 */
	public TextContainerListTest(String name)
	{
		super(name);
	} // TextContainerListTest() 

	// =========================================================================
	// PUBLIC CLASS METHODS
	// =========================================================================
	public static Test suite()
	{
		return new TestSuite(TextContainerListTest.class);
	} // suite() 

	// =========================================================================
	// TEST METHODS
	// =========================================================================

	public void test_getText_1() throws Exception
	{
		Locale[] locales = { Locale.GERMAN, Locale.ENGLISH };
		ITextProvider provider;
		NLSIniFileLoader loader = new NLSIniFileLoader();

		provider = loader.loadText(FILE_1, locales);
		assertEquals("Datei schließen", provider.getText("label.close.file"));
		assertEquals("Export all data to a CSV file", provider.getText("help.export.csv"));
		assertEquals("Wir laden Sie herzlich ein", provider.getText("msg.invitation"));
	} // test_getText_1() 

	// -------------------------------------------------------------------------

	public void test_getText_2() throws Exception
	{
		Locale[] locales = { Locale.ENGLISH, Locale.GERMAN };
		ITextProvider provider;
		NLSIniFileLoader loader = new NLSIniFileLoader();

		provider = loader.loadText(FILE_1, locales);
		assertEquals("Close File", provider.getText("label.close.file"));
		assertEquals("Export all data to a CSV file", provider.getText("help.export.csv"));
		assertEquals("Wir laden Sie herzlich ein", provider.getText("msg.invitation"));
	} // test_getText_2() 

	// -------------------------------------------------------------------------

	public void test_getText_3() throws Exception
	{
		Locale[] locales = { Locale.GERMAN, Locale.ENGLISH };
		Locale[] order = { Locale.ENGLISH, Locale.GERMAN };
		TextContainerList provider;
		NLSIniFileLoader loader = new NLSIniFileLoader();

		provider = loader.loadText(FILE_1, locales);
		provider.setLookupOrder(order);
		assertEquals("Close File", provider.getText("label.close.file"));
		assertEquals("Export all data to a CSV file", provider.getText("help.export.csv"));
		assertEquals("Wir laden Sie herzlich ein", provider.getText("msg.invitation"));
	} // test_getText_3() 

	// -------------------------------------------------------------------------

	public void test_getText_4() throws Exception
	{
		Locale[] locales = { Locale.GERMAN };
		Locale[] order = { Locale.ENGLISH, Locale.GERMAN };
		TextContainerList provider;
		NLSIniFileLoader loader = new NLSIniFileLoader();

		provider = loader.loadText(FILE_1, locales);
		provider.setLookupOrder(order);
		assertEquals("Datei schließen", provider.getText("label.close.file"));
		assertNull(provider.getText("help.export.csv"));
		assertEquals("Wir laden Sie herzlich ein", provider.getText("msg.invitation"));
	} // test_getText_3() 

	// -------------------------------------------------------------------------

	// =========================================================================
	// PROTECTED INSTANCE METHODS
	// =========================================================================
	@Override
  protected void setUp() throws Exception
	{
		super.setUp();
	} // setUp() 

	// -------------------------------------------------------------------------

} // class TextContainerListTest 
