// ===========================================================================
// CONTENT  : TEST CLASS TextContainerTest
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 24/03/2006
// HISTORY  :
//  24/03/2006  duma  CREATED
//
// Copyright (c) 2006, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pf.nls ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.util.Locale;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.pf.text.StringUtil;

/**
 * Test class for corresponding business class.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class TextContainerTest extends TestCase
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
	protected static String KEY_1 = "key_1" ;
	protected static String KEY_2 = "key_2" ;
	protected static String KEY_3 = "key_3" ;

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
	private TextContainer textContainer1 ;
	private TextContainer textContainer2 ;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public TextContainerTest( String name )
  {
    super( name ) ;
  } // TextContainerTest() 

  // =========================================================================
  // PUBLIC CLASS METHODS
  // =========================================================================
  public static Test suite()
  {
		return new TestSuite( TextContainerTest.class ) ;
	} // suite() 

  // =========================================================================
  // TEST METHODS
  // =========================================================================

  public void test_default_1()
  {
  	assertEquals( "Amazonas", textContainer1.getText( KEY_1 ) ) ;
  	assertNull( textContainer1.getText( KEY_3 ) ) ;
  	assertNull( textContainer1.getText( "unknown.key" ) ) ;

  	textContainer1.setDefaultProvider( textContainer2 ) ;
  	assertEquals( "Amazonas", textContainer1.getText( KEY_1 ) ) ;
  	assertEquals( "Wolga", textContainer1.getText( KEY_3 ) ) ;
  	assertNull( textContainer1.getText( "unknown.key" ) ) ;
  } // test_default_1() 

  // -------------------------------------------------------------------------

  public void test_getKeys_1() 
	{
		String[] keys ;
		
		keys = textContainer1.getKeys() ;
		assertTrue( str().contains( keys, KEY_1 ) ) ;
		assertTrue( str().contains( keys, KEY_2 ) ) ;
		assertTrue( ! str().contains( keys, KEY_3 ) ) ;
	} // test_getKeys_1() 
	
	// -------------------------------------------------------------------------
  
  public void test_isEmpty_1() 
  {
  	assertTrue( ! textContainer2.isEmpty() ) ;
  } // test_isEmpty_1() 
  
  // -------------------------------------------------------------------------
  
  public void test_isEmpty_2() 
  {
  	TextContainer container = new TextContainer(Locale.ITALIAN) ;
  	assertTrue( container.isEmpty() ) ;
  } // test_isEmpty_2() 
  
  // -------------------------------------------------------------------------
  
  public void test_isEmpty_3() 
  {
  	TextContainer container = new TextContainer(Locale.ITALIAN) ;
  	container.setDefaultProvider( textContainer1 ) ;
  	assertTrue( container.isEmpty() ) ;
  } // test_isEmpty_3() 
  
  // -------------------------------------------------------------------------
  
  public void test_containsNothing_1() 
  {
  	assertTrue( ! textContainer2.containsNothing() ) ;
  } // test_containsNothing_1() 
  
  // -------------------------------------------------------------------------
  
  public void test_containsNothing_2() 
  {
  	TextContainer container = new TextContainer(Locale.ITALIAN) ;
  	assertTrue( container.containsNothing() ) ;
  } // test_containsNothing_2() 
  
  // -------------------------------------------------------------------------
  
  public void test_containsNothing_3() 
  {
  	TextContainer container = new TextContainer(Locale.ITALIAN) ;
  	container.setDefaultProvider( textContainer1 ) ;
  	assertTrue( !container.containsNothing() ) ;
  } // test_containsNothing_3() 
  
  // -------------------------------------------------------------------------
  
  public void test_containsNothing_4() 
  {
  	TextContainer container = new TextContainer(Locale.ITALIAN) ;
  	TextContainer container1 = new TextContainer(Locale.ITALIAN) ;
  	container.setDefaultProvider( container1 ) ;
  	assertTrue( container.containsNothing() ) ;
  } // test_containsNothing_4() 
  
  // -------------------------------------------------------------------------
  
  public void test_containsNothing_5() 
  {
  	TextContainer container = new TextContainer(Locale.ITALIAN) ;
  	TextContainer container1 = new TextContainer(Locale.ITALIAN) ;
  	container.setDefaultProvider( container1 ) ;
  	container1.setDefaultProvider( textContainer2) ;
  	assertTrue( ! container.containsNothing() ) ;
  } // test_containsNothing_5() 
  
  // -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  @Override
  protected void setUp()
    throws Exception
  {
    super.setUp() ;
    this.initTextContainer1() ;
    this.initTextContainer2() ;
	} // setUp() 

  // -------------------------------------------------------------------------

  protected void initTextContainer1() 
	{
		textContainer1 = new TextContainer( Locale.ENGLISH ) ;
		
		textContainer1.addText( KEY_1, "Amazonas" ) ;
		textContainer1.addText( KEY_2, "Mississippi" ) ;
	} // initTextContainer1() 
	
	// -------------------------------------------------------------------------
  
  protected void initTextContainer2() 
  {
  	textContainer2 = new TextContainer( Locale.ENGLISH ) ;
  	
  	textContainer2.addText( KEY_1, "Nil" ) ;
  	textContainer2.addText( KEY_3, "Wolga" ) ;
  } // initTextContainer2() 
  
  // -------------------------------------------------------------------------
  
  protected StringUtil str()
	{
		return StringUtil.current();
	} // str() 

	//-------------------------------------------------------------------------
  
} // class TextContainerTest 
