// ===========================================================================
// CONTENT  : CLASS MergeTool
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 24/03/2006
// HISTORY  :
//  24/03/2006  mdu  CREATED
//
// Copyright (c) 2006, by M.Duchrow. All rights reserved.
// ===========================================================================
package org.pf.nls.tools ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.io.File;
import java.util.Locale;

import org.pf.nls.NLSUtil;
import org.pf.settings.Settings;
import org.pf.settings.impl.SettingsImpl;
import org.pf.settings.rw.IniReaderWriter;
import org.pf.settings.rw.PropertiesReaderWriter;
import org.pf.text.CommandLineArguments;

/**
 * This tool allows to add texts from a properties file to an NLS-ini file.
 *
 * @author M.Duchrow
 * @version 1.0
 */
public class MergeTool
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
	private static final String OPT_PROPERTIES_FILE				= "-prop" ;
	private static final String OPT_INI_FILE							= "-ini" ;
	private static final String OPT_LOCALE								= "-locale" ;

	private static final String DEFAULT_ENCODING					= "UTF-8" ;

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================

  // =========================================================================
  // CLASS METHODS
  // =========================================================================
  public static void main( String[] args )
  {
  	MergeTool inst ;
  	
  	inst = new MergeTool() ;
  	inst.run( args ) ;
  	System.exit(0) ;
  } // main() 


  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public MergeTool()
  {
    super() ;
  } // MergeTool() 

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public void run( String[] args ) 
	{
		CommandLineArguments options ;
		File propertiesFile ;
		File iniFile ;
		Locale locale ;
		
		options = new CommandLineArguments( args ) ;
		propertiesFile = new File( options.getArgumentValue( OPT_PROPERTIES_FILE ) ) ;
		iniFile = new File( options.getArgumentValue( OPT_INI_FILE ) ) ;
		locale = NLSUtil.current().createLocale( options.getArgumentValue( OPT_LOCALE ) ) ;
		this.merge( propertiesFile, iniFile, locale ) ;
	} // run() 
	
	// -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected void merge( File propertiesFile, File iniFile, Locale locale ) 
	{
		IniReaderWriter iniReaderWriter ;
		PropertiesReaderWriter propReader ;
		Settings iniSettings ;
		Settings propSettings ;
		String localeName ;
		String[] keyNames ;

		localeName = locale.toString() ;
		iniReaderWriter = new IniReaderWriter( iniFile.getAbsolutePath(), DEFAULT_ENCODING ) ;
		if ( iniFile.exists() )
		{
			iniSettings = iniReaderWriter.loadSettings() ;
		}
		else
		{
			iniSettings = new SettingsImpl() ;
		}
		propReader = new PropertiesReaderWriter( propertiesFile.getAbsolutePath(), DEFAULT_ENCODING ) ;
		propSettings = propReader.loadSettings() ;
		keyNames = propSettings.getKeyNamesOfDefaultCategory() ;
		for (int i = 0; i < keyNames.length; i++ )
		{
			iniSettings.setValueOf( keyNames[i], localeName, propSettings.getValueOf( keyNames[i] ) ) ;
		}
		iniReaderWriter.storeSettings( iniSettings ) ;
	} // merge() 
	
	// -------------------------------------------------------------------------
  
} // class MergeTool 
